@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{Astro::Coord::ECI::TLE};
 
-our $VERSION = '0.098_01';
+our $VERSION = '0.098_02';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils qw{:all};
@@ -1685,12 +1685,10 @@ sub _set_operational_status {
     }
 }
 
-# Status
-
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Wed Jun 20 15:13:55 2018 GMT
+# on Thu Jun 21 13:01:02 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1730,7 +1728,7 @@ __PACKAGE__->status( add => 24967, iridium => '-', 'Iridium 36', 'Tumbling' );
 __PACKAGE__->status( add => 24968, iridium => 'D', 'Iridium 37', 'Decayed 2018-05-26' );
 __PACKAGE__->status( add => 24969, iridium => 'D', 'Iridium 34', 'Decayed 2018-01-08' );
 __PACKAGE__->status( add => 25039, iridium => 'D', 'Iridium 43', 'Decayed 2018-02-11' );
-__PACKAGE__->status( add => 25040, iridium => '+', 'Iridium 41', '' );
+__PACKAGE__->status( add => 25040, iridium => 'S', 'Iridium 41', '' );
 __PACKAGE__->status( add => 25041, iridium => '-', 'Iridium 40', 'Tumbling' );
 __PACKAGE__->status( add => 25042, iridium => '-', 'Iridium 39', 'Tumbling' );
 __PACKAGE__->status( add => 25043, iridium => '-', 'Iridium 38', 'Tumbling' );
@@ -1758,7 +1756,7 @@ __PACKAGE__->status( add => 25286, iridium => '-', 'Iridium 63', 'Tumbling' );
 __PACKAGE__->status( add => 25287, iridium => 'S', 'Iridium 64', '' );
 __PACKAGE__->status( add => 25288, iridium => '+', 'Iridium 65', '' );
 __PACKAGE__->status( add => 25289, iridium => 'S', 'Iridium 66', '' );
-__PACKAGE__->status( add => 25290, iridium => 'S', 'Iridium 67', '' );
+__PACKAGE__->status( add => 25290, iridium => '-', 'Iridium 67', 'Tumbling' );
 __PACKAGE__->status( add => 25291, iridium => 'D', 'Iridium 68', 'Decayed 2018-06-06' );
 __PACKAGE__->status( add => 25319, iridium => '-', 'Iridium 69', 'Tumbling' );
 __PACKAGE__->status( add => 25320, iridium => '-', 'Iridium 71', 'Tumbling' );
@@ -1792,9 +1790,9 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => '+', 'Iridium 98', '' );
 
 # Summary:
-# Operational [+]: 21
+# Operational [+]: 20
 #       Spare [S]: 17
-#    Tumbling [-]: 36
+#    Tumbling [-]: 37
 #     Decayed [D]: 23
 
 1;
